abctools.Parser
===============

.. abjad-lineage:: abjad.tools.abctools.Parser.Parser

.. autoclass:: abjad.tools.abctools.Parser.Parser

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.abctools.Parser.Parser.debug
      ~abjad.tools.abctools.Parser.Parser.lexer
      ~abjad.tools.abctools.Parser.Parser.lexer_rules_object
      ~abjad.tools.abctools.Parser.Parser.logger
      ~abjad.tools.abctools.Parser.Parser.logger_path
      ~abjad.tools.abctools.Parser.Parser.output_path
      ~abjad.tools.abctools.Parser.Parser.parser
      ~abjad.tools.abctools.Parser.Parser.parser_rules_object
      ~abjad.tools.abctools.Parser.Parser.pickle_path
      ~abjad.tools.abctools.Parser.Parser.tokenize
      ~abjad.tools.abctools.Parser.Parser.__call__
      ~abjad.tools.abctools.Parser.Parser.__eq__
      ~abjad.tools.abctools.Parser.Parser.__format__
      ~abjad.tools.abctools.Parser.Parser.__hash__
      ~abjad.tools.abctools.Parser.Parser.__ne__
      ~abjad.tools.abctools.Parser.Parser.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.abctools.Parser.Parser.debug
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.lexer
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.lexer_rules_object
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.logger
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.logger_path
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.output_path
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.parser
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.parser_rules_object
   :noindex:

.. autoattribute:: abjad.tools.abctools.Parser.Parser.pickle_path
   :noindex:

Methods
-------

.. automethod:: abjad.tools.abctools.Parser.Parser.tokenize
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.abctools.Parser.Parser.__call__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.__eq__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.__format__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.__hash__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.__ne__
   :noindex:

.. automethod:: abjad.tools.abctools.Parser.Parser.__repr__
   :noindex:
